@@ -8,10 +8,21 @@ import re
 import pyconvox
 
 
+def Apps(args,apps,parser):
+    if args.app:
+        if args.app in apps:
+            stream = os.popen(f"xovnoc apps")
+            envs = str(stream.read()).strip().split('\n')
+        else:
+            parser.print_help()
+    else:
+        print('Please specify the application name using --app / -a <application_name>')
+
+
 def Env(args,apps,parser):
     if args.app:
         if args.app in apps:
-            stream = os.popen(f"convox env -a {args.app}")
+            stream = os.popen(f"xovnoc env -a {args.app}")
             envs = str(stream.read()).strip().split('\n')
             for envvar in envs:
                 print(f'{envvar}')
@@ -32,9 +43,9 @@ def SetEnv(args,apps,parser):
             while option not in 'Y,y,N,n'.split(','):
                 option=str(input("Would you like pyconvox to promote the new release? (Y/N): ")).strip()
                 if option == 'Y' or option == 'y':
-                    stream = os.system(f"convox env set {' '.join([ vars for vars in args.envvars])} -a {args.app} -p -w")
+                    stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app} -p -w")
                 elif option == 'N' or option == 'n':
-                    stream = os.system(f"convox env set {' '.join([ vars for vars in args.envvars])} -a {args.app}")
+                    stream = os.system(f"xovnoc env set {' '.join([ vars for vars in args.envvars])} -a {args.app}")
                 else:
                     print("Only Y or N accepted!")
             # print(args.app)
@@ -51,7 +62,7 @@ def SetEnv(args,apps,parser):
 def Scale(args,apps,parser):
     if args.app:
         if args.app in apps:
-            stream = os.system(f"convox scale -a {args.app}")
+            stream = os.system(f"xovnoc scale -a {args.app}")
         else:
             print("Wrong Application Name!!..\nPlease provide application name from the below")
             for index,appname in enumerate(apps):
@@ -64,7 +75,7 @@ def Scale(args,apps,parser):
 def PS(args,apps,parser):
     if args.app:
         if args.app in apps:
-            stream = os.system(f"convox ps -a {args.app}")
+            stream = os.system(f"xovnoc ps -a {args.app}")
         else:
             print("Wrong Application Name!!..\nPlease provide application name from the below")
             for index,appname in enumerate(apps):
@@ -77,7 +88,7 @@ def PS(args,apps,parser):
 def Releases(args,apps,parser):
     if args.app:
         if args.app in apps:
-            stream = os.system(f"convox releases -a {args.app}")
+            stream = os.system(f"xovnoc releases -a {args.app}")
         else:
             print("Wrong Application Name!!..\nPlease provide application name from the below")
             for index,appname in enumerate(apps):
@@ -90,7 +101,7 @@ def Releases(args,apps,parser):
 def Logs(args,apps,parser):
     if args.app:
         if args.app in apps:
-            stream = os.system(f"convox logs -a {args.app}")
+            stream = os.system(f"xovnoc logs -a {args.app}")
         else:
             print("Wrong Application Name!!..\nPlease provide application name from the below")
             for index,appname in enumerate(apps):
@@ -101,7 +112,7 @@ def Logs(args,apps,parser):
         print('Please specify the application name using --app / -a <application_name>')
 
 def Instances(args,apps,parser):
-        stream = os.system(f"convox instances")
+        stream = os.system(f"xovnoc instances")
 
 
 
@@ -111,10 +122,10 @@ def RailsC(args,apps,parser):
             if args.service:
                 service=str(args.service)
             else:
-                stream = os.popen(f"convox scale -a {args.app} | grep -v SERVICE | grep -E 'web|rake' | awk '"+"{print $1}' | head -n 1")
+                stream = os.popen(f"xovnoc scale -a {args.app} | grep -v SERVICE | grep -E 'web|rake' | awk '"+"{print $1}' | head -n 1")
                 service = str(stream.read()).strip()
             print(service)
-            stream = os.system(f"convox run {service} 'rails c' -a {args.app}")
+            stream = os.system(f"xovnoc run {service} 'rails c' -a {args.app}")
             # console = str(stream.read()).strip()
             print(stream)
         else:
@@ -167,7 +178,7 @@ def main():
     parser_g.set_defaults(which='ps')
 
     args = parser.parse_args()
-    stream = os.popen("convox apps | grep -v APP | awk '{print $1}'")
+    stream = os.popen("xovnoc apps | grep -v APP | awk '{print $1}'")
     apps = str(stream.read()).strip().split('\n')
     # print(apps)
 
@@ -188,6 +199,8 @@ def main():
             Releases(args,apps,parser)
         elif args.which == 'ps':
             PS(args,apps,parser)
+        elif args.which == 'apps':
+            Apps(args,apps,parser)
         else:
             parser.print_help()
 
